# Hotwire/Turbo helpers for Django, inspired by Rails.

[![PyPI version](https://badge.fury.io/py/django-turbo-helper.svg)](https://badge.fury.io/py/django-turbo-helper)
[![Documentation](https://img.shields.io/badge/Documentation-link-green.svg)](https://django-turbo-helper.readthedocs.io/)

## Documentation

**`django-turbo-response` has been renamed to `django-turbo-helper` since version 2.x.x**

1. For legacy `django-turbo-response` user, please check https://django-turbo-helper.readthedocs.io/en/1.0.3/
2. For `django-turbo-helper` user, please check https://django-turbo-helper.readthedocs.io/

## Free Hotwire Django eBook

If you are new to Hotwire, you may be interested in this free eBook [Hotwire Django Tutorial](https://tutorial.saashammer.com/).
